@@ -20,7 +20,7 @@ from testflows._core.cli.arg.handlers.report.totals import Handler as totals_han
 from testflows._core.cli.arg.handlers.report.fails import Handler as fails_handler
 from testflows._core.cli.arg.handlers.report.version import Handler as version_handler
 from testflows._core.cli.arg.handlers.report.official import Handler as official_handler
-from testflows._core.cli.arg.handlers.report.compare import Handler as compare_handler
+from testflows._core.cli.arg.handlers.report.compare.handler import Handler as compare_handler
 from testflows._core.cli.arg.handlers.report.requirements import Handler as requirements_handler
 from testflows._core.cli.arg.handlers.report.map.handler import Handler as map_handler
 
