@@ -13,6 +13,8 @@
 # limitations under the License.
 import threading
 
+from testflows._core.message import Message, ResultMessages
+from testflows._core.testtype import TestType
 from .read import transform as read_transform
 from .parse import transform as parse_transform
 from .nice import transform as nice_transform
@@ -21,6 +23,7 @@ from .write import transform as write_transform
 from .stop import transform as stop_transform
 from .raw import transform as raw_transform
 from .short import transform as short_transform
+from .slick import transform as slick_transform
 from .index import transform as index_transform
 from .read_and_filter import transform as read_and_filter_transform
 from .report.passing import transform as passing_report_transform
@@ -28,6 +31,7 @@ from .report.fails import transform as fails_report_transform
 from .report.totals import transform as totals_report_transform
 from .report.version import transform as version_report_transform
 from .report.results import transform as results_transform
+from .report.map import transform as map_transform
 
 class Pipeline(object):
     """Combines multiple steps into a pipeline
@@ -136,6 +140,28 @@ class NiceLogPipeline(Pipeline):
         ]
         super(NiceLogPipeline, self).__init__(steps)
 
+class SlickLogPipeline(Pipeline):
+    def __init__(self, input, output, tail=False):
+        stop_event = threading.Event()
+
+        steps = [
+            read_transform(input, tail=tail),
+            parse_transform(stop_event),
+            fanout(
+                slick_transform(),
+                passing_report_transform(stop_event),
+                fails_report_transform(stop_event),
+                totals_report_transform(stop_event),
+                version_report_transform(stop_event),
+            ),
+            fanin(
+                "".join
+            ),
+            write_transform(output),
+            stop_transform(stop_event)
+        ]
+        super(SlickLogPipeline, self).__init__(steps)
+
 class DotsLogPipeline(Pipeline):
     def __init__(self, input, output, tail=False):
         stop_event = threading.Event()
@@ -159,11 +185,14 @@ class DotsLogPipeline(Pipeline):
         super(DotsLogPipeline, self).__init__(steps)
 
 class TotalsReportLogPipeline(Pipeline):
-    def __init__(self, input, output, tail=False):
+    def __init__(self, input, output):
         stop_event = threading.Event()
 
+        message_types = [Message.TEST] + ResultMessages
+        command = f"grep -E '^({'|'.join([str(int(i)) for i in message_types])}),'"
+
         steps = [
-            read_transform(input, tail=tail),
+            read_and_filter_transform(input, command=command),
             parse_transform(stop_event),
             fanout(
                 totals_report_transform(stop_event),
@@ -177,11 +206,14 @@ class TotalsReportLogPipeline(Pipeline):
         super(TotalsReportLogPipeline, self).__init__(steps)
 
 class FailsReportLogPipeline(Pipeline):
-    def __init__(self, input, output, tail=False):
+    def __init__(self, input, output):
         stop_event = threading.Event()
 
+        message_types = [Message.TEST] + ResultMessages
+        command = f"grep -E '^({'|'.join([str(int(i)) for i in message_types])}),'"
+
         steps = [
-            read_transform(input, tail=tail),
+            read_and_filter_transform(input, command=command),
             parse_transform(stop_event),
             fanout(
                 fails_report_transform(stop_event),
@@ -194,12 +226,36 @@ class FailsReportLogPipeline(Pipeline):
         ]
         super(FailsReportLogPipeline, self).__init__(steps)
 
-class VersionReportLogPipeline(Pipeline):
-    def __init__(self, input, output, tail=False):
+class PassingReportLogPipeline(Pipeline):
+    def __init__(self, input, output):
         stop_event = threading.Event()
 
+        message_types = [Message.TEST] + ResultMessages
+        command = f"grep -E '^({'|'.join([str(int(i)) for i in message_types])}),'"
+
         steps = [
-            read_transform(input, tail=tail),
+            read_and_filter_transform(input, command=command),
+            parse_transform(stop_event),
+            fanout(
+                passing_report_transform(stop_event),
+            ),
+            fanin(
+                "".join
+            ),
+            write_transform(output),
+            stop_transform(stop_event)
+        ]
+        super(PassingReportLogPipeline, self).__init__(steps)
+
+class VersionReportLogPipeline(Pipeline):
+    def __init__(self, input, output):
+        stop_event = threading.Event()
+
+        message_types = [Message.VERSION] + ResultMessages
+        command = f"grep -E '^({'|'.join([str(int(i)) for i in message_types])}),'"
+
+        steps = [
+            read_and_filter_transform(input, command=command),
             parse_transform(stop_event),
             fanout(
                 version_report_transform(stop_event),
@@ -212,26 +268,59 @@ class VersionReportLogPipeline(Pipeline):
         ]
         super(VersionReportLogPipeline, self).__init__(steps)
 
+class MapLogPipeline(Pipeline):
+    def __init__(self, input, maps):
+        stop_event = threading.Event()
+        message_types = [Message.TEST]
+        command = f"grep -m1 -E '^({'|'.join([str(int(i)) for i in message_types])}),'"
+
+        steps = [
+            read_and_filter_transform(input, command=command),
+            parse_transform(stop_event),
+            map_transform(maps, stop_event),
+            stop_transform(stop_event)
+        ]
+        super(MapLogPipeline, self).__init__(steps)
+
 class ResultsLogPipeline(Pipeline):
     def __init__(self, input, results):
         stop_event = threading.Event()
+        message_types = [Message.VERSION, Message.TEST] + ResultMessages
+        command = f"grep -E '^({'|'.join([str(int(i)) for i in message_types])}),'"
 
         steps = [
-            read_transform(input),
+            read_and_filter_transform(input, command=command),
             parse_transform(stop_event),
             results_transform(results, stop_event),
             stop_transform(stop_event)
         ]
         super(ResultsLogPipeline, self).__init__(steps)
 
+class CompactRawLogPipeline(Pipeline):
+    def __init__(self, input, output, steps=True):
+        stop_event = threading.Event()
+        message_types = [Message.VERSION, Message.TEST] + ResultMessages
+        test_types = [TestType.Module, TestType.Suite, TestType.Test]
+        command = (f"grep -E '^({'|'.join([str(int(i)) for i in message_types])}),"
+            + (f"\"[^\"]+\",[0-9]+,({'|'.join([str(t) for t in test_types])})," if not steps else "")
+            + "'")
+
+        steps = [
+            read_and_filter_transform(input, command=command),
+            raw_transform(stop_event),
+            write_transform(output),
+            stop_transform(stop_event)
+        ]
+        super(CompactRawLogPipeline, self).__init__(steps)
+
 class IndexLogPipeline(Pipeline):
-    def __init__(self, input, output, tail=False):
+    def __init__(self, input, output):
         stop_event = threading.Event()
 
         steps = [
-            read_and_filter_transform(input, command="grep -E '^1,'", tail=tail),
+            read_and_filter_transform(input, command=f"grep -E '^{Message.TEST},'"),
             index_transform(stop_event),
             write_transform(output),
             stop_transform(stop_event)
         ]
-        super(IndexLogPipeline, self).__init__(steps)
\ No newline at end of file
+        super(IndexLogPipeline, self).__init__(steps)
