@@ -56,6 +56,32 @@ class Counts(object):
     def __bool__(self):
         return self.units > 0
 
+    def __data__(self):
+        data = {}
+        counts = {}
+        data["units"] = self.units
+        data["name"] = self.name if self.units != 1 else self.name.rstrip('s')
+        data["counts"] = counts
+        if self.ok > 0:
+            counts["OK"] = self.ok
+        if self.fail > 0:
+            counts["Fail"] = self.fail
+        if self.skip > 0:
+            counts["Skip"] = self.skip
+        if self.error > 0:
+            counts["Error"] = self.error
+        if self.null > 0:
+            counts["Null"] = self.null
+        if self.xok > 0:
+            counts["XOK"] = self.xok
+        if self.xfail > 0:
+            counts["XFail"] = self.xfail
+        if self.xerror > 0:
+            counts["XError"] = self.xerror
+        if self.xnull > 0:
+            counts["XNull"] = self.xnull
+        return data
+
     def __str__(self):
         s = f"{self.units} {self.name if self.units != 1 else self.name.rstrip('s')} ("
         s = color(s, "white", attrs=["bold"])
@@ -149,12 +175,8 @@ formatters = {
     message.RawResultXNull: (format_result,)
 }
 
-def transform(stop):
-    """Totals report.
-
-    :param stop: stop event
-    """
-    counts = {
+def all_counts():
+    return {
         "module": Counts("modules", *([0] * 10)),
         "suite": Counts("suites", *([0] * 10)),
         "test": Counts("tests", *([0] * 10)),
@@ -163,6 +185,13 @@ def transform(stop):
         "feature": Counts("features", *([0] * 10)),
         "scenario": Counts("scenarios", *([0] * 10))
     }
+
+def transform(stop):
+    """Totals report.
+
+    :param stop: stop event
+    """
+    counts = all_counts()
     line = None
 
     while True:
